summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorjai <jai@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>2007-01-21 00:23:58 +0000
committerjai <jai@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>2007-01-21 00:23:58 +0000
commite02a3fc410dba05bdd52be34fa32d2dd6415b67b (patch)
treecf71ac06a71bca7b1933407f3c5e62296ba42d8f
parent807c7c81fd564e7ea07bac60cbecb0f5012421c3 (diff)
downloadATCD-e02a3fc410dba05bdd52be34fa32d2dd6415b67b.tar.gz
adding DiffServ library
-rw-r--r--TAO/tao/DiffServPolicy/DiffServPolicy_Factory.h23
1 files changed, 9 insertions, 14 deletions
diff --git a/TAO/tao/DiffServPolicy/DiffServPolicy_Factory.h b/TAO/tao/DiffServPolicy/DiffServPolicy_Factory.h
index 0d7877c9489..201e396ae88 100644
--- a/TAO/tao/DiffServPolicy/DiffServPolicy_Factory.h
+++ b/TAO/tao/DiffServPolicy/DiffServPolicy_Factory.h
@@ -2,26 +2,23 @@
//=============================================================================
/**
- * @file RT_PolicyFactory.h
+ * @file DiffServPolicy_Factory.h
*
* $Id$
*
- * @author Angelo Corsaro <corsaro@cs.wustl.edu>
- * @author Ossama Othman <ossama@uci.edu>
+ * @author Jaiganesh Balasubramanian <jai@dre.vanderbilt.edu>
+ * @author Johnny Willemsen <jwillemsen@remedy.nl>
*/
//=============================================================================
-#ifndef TAO_RT_POLICY_FACTORY_H
-#define TAO_RT_POLICY_FACTORY_H
+#ifndef TAO_DIFFSERV_POLICY_FACTORY_H
+#define TAO_DIFFSERV_POLICY_FACTORY_H
#include /**/ "ace/pre.h"
#include "tao/orbconf.h"
-
-#if defined (TAO_HAS_CORBA_MESSAGING) && TAO_HAS_CORBA_MESSAGING != 0
-
-#include "tao/RTCORBA/rtcorba_export.h"
+#include "tao/DiffServPolicy/DiffServPolicy_Export.h"
#if !defined (ACE_LACKS_PRAGMA_ONCE)
# pragma once
@@ -39,8 +36,8 @@
TAO_BEGIN_VERSIONED_NAMESPACE_DECL
-/// Policy factory for all RTCORBA related policies.
-class TAO_RT_PolicyFactory
+/// Policy factory for all DiffServ related policies.
+class TAO_DiffServ_PolicyFactory
: public virtual PortableInterceptor::PolicyFactory,
public virtual TAO_Local_RefCounted_Object
{
@@ -64,8 +61,6 @@ TAO_END_VERSIONED_NAMESPACE_DECL
#pragma warning(pop)
#endif /* _MSC_VER */
-#endif /* TAO_HAS_CORBA_MESSAGING && TAO_HAS_CORBA_MESSAGING != 0 */
-
#include /**/ "ace/post.h"
-#endif /* TAO_RT_POLICY_FACTORY_H */
+#endif /* TAO_DIFFSERV_POLICY_FACTORY_H */